@@ -48,7 +48,7 @@ QmlComponentsPool *QmlComponentsPoolSingleton::instance(QQmlEngine *engine)
     componentPool = new QmlComponentsPool(engine);
 
     const auto removePool = [engine]() {
-        // NB: do not derefence engine. it may be dangling already!
+        // NB: do not dereference engine. it may be dangling already!
         if (privateQmlComponentsPoolSelf) {
             privateQmlComponentsPoolSelf->m_instances.remove(engine);
         }
@@ -710,7 +710,7 @@ void ContentItem::layoutItems()
     m_view->setImplicitWidth(implicitWidth);
     m_view->setImplicitHeight(implicitHeight + m_view->topPadding() + m_view->bottomPadding());
 
-    const qreal newContentX = m_viewAnchorItem ? -m_viewAnchorItem->x() : 0.0;
+    const qreal newContentX = (m_viewAnchorItem ? -m_viewAnchorItem->x() : 0.0) + m_leftPinnedSpace;
     if (m_shouldAnimate) {
         animateX(newContentX);
     } else {
@@ -837,6 +837,10 @@ void ContentItem::forgetItem(QQuickItem *item)
     }
 
     if (QQuickItem *header = attached->globalHeader()) {
+        // disconnecting before hiding avoids one extra layoutItems,
+        // which would try to recreate separatorItem.
+        // Which might crash if we are doing this during item destruction
+        disconnect(header, nullptr, this, nullptr);
         header->setVisible(false);
         header->setParentItem(item);
         separatorItem = m_separators.take(header);
@@ -845,6 +849,7 @@ void ContentItem::forgetItem(QQuickItem *item)
         }
     }
     if (QQuickItem *footer = attached->globalFooter()) {
+        disconnect(footer, nullptr, this, nullptr);
         footer->setVisible(false);
         footer->setParentItem(item);
         separatorItem = m_separators.take(footer);
@@ -1119,9 +1124,9 @@ void ColumnView::setCurrentIndex(int index)
             mappedCurrent.moveLeft(mappedCurrent.left() + m_contentItem->x() + m_contentItem->m_slideAnim->endValue().toInt());
         }
 
-        // m_contentItem->m_slideAnim->stop();
+        ColumnViewAttached *attached = qobject_cast<ColumnViewAttached *>(qmlAttachedPropertiesObject<ColumnView>(m_currentItem, true));
 
-        QRectF contentsRect(m_contentItem->m_leftPinnedSpace, //
+        QRectF contentsRect(attached->isPinned() ? 0 : m_contentItem->m_leftPinnedSpace,
                             0,
                             width() - m_contentItem->m_rightPinnedSpace - m_contentItem->m_leftPinnedSpace,
                             height());
@@ -1683,6 +1688,19 @@ bool ColumnView::childMouseEventFilter(QQuickItem *item, QEvent *event)
     }
 
     switch (event->type()) {
+    case QEvent::MouseButtonPress: {
+        // On press, we set the current index of the view to the root item,
+        // this needs to be done on both mouse and touch input
+        QQuickItem *candidateItem = item;
+        while (candidateItem->parentItem() && candidateItem->parentItem() != m_contentItem) {
+            candidateItem = candidateItem->parentItem();
+        }
+        if (int idx = m_contentItem->m_items.indexOf(candidateItem); idx >= 0 && candidateItem->parentItem() == m_contentItem) {
+            setCurrentIndex(idx);
+        }
+        event->setAccepted(false);
+        break;
+    }
     case QEvent::TouchBegin: {
         QTouchEvent *te = static_cast<QTouchEvent *>(event);
 
